"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Transport = require("winston-transport");
var appInsights = require("applicationinsights");
var Contracts_1 = require("applicationinsights/out/Declarations/Contracts");
var DEFAULT_LEVEL = 'info';
var DEFAULT_SILENT = false;
var winstonLevelsMap = {
    emerg: Contracts_1.SeverityLevel.Critical,
    crit: Contracts_1.SeverityLevel.Critical,
    error: Contracts_1.SeverityLevel.Error,
    warn: Contracts_1.SeverityLevel.Warning,
    warning: Contracts_1.SeverityLevel.Warning,
    notice: Contracts_1.SeverityLevel.Information,
    info: Contracts_1.SeverityLevel.Information,
    verbose: Contracts_1.SeverityLevel.Verbose,
    debug: Contracts_1.SeverityLevel.Verbose,
    silly: Contracts_1.SeverityLevel.Verbose,
};
/**
 *
 * @param winstonLevel
 */
function getLevelAi(winstonLevel) {
    return winstonLevel in winstonLevelsMap ? winstonLevelsMap[winstonLevel] : Contracts_1.SeverityLevel.Information;
}
var ApplicationInsightsTransport = /** @class */ (function (_super) {
    __extends(ApplicationInsightsTransport, _super);
    function ApplicationInsightsTransport(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        // if ai instance provided, use it
        if (options.client) {
            _this._client = options.client;
        }
        else if (options.appInsights) {
            _this._client = options.appInsights.defaultClient;
        }
        else {
            appInsights
                .setup(options.key)
                .start();
            _this._client = appInsights.defaultClient;
        }
        _this._silent = options.silent || DEFAULT_SILENT;
        _this._level = options.level || DEFAULT_LEVEL;
        _this._handleExceptions = options.handleExceptions || false;
        if (!_this._client) {
            throw new Error('No Application Insights client instance found');
        }
        return _this;
    }
    ApplicationInsightsTransport.prototype.log = function (info, callback) {
        var level = info.level;
        var message = info.message;
        var meta = __assign({}, info);
        delete meta.level;
        delete meta.message;
        var aiLevel = getLevelAi(level);
        this._client.trackTrace({
            message: message,
            severity: aiLevel,
            properties: meta,
        });
        callback();
    };
    return ApplicationInsightsTransport;
}(Transport));
exports.ApplicationInsightsTransport = ApplicationInsightsTransport;
;
//# sourceMappingURL=index.js.map